# Argosim
Argosim is a python package for radio interferometric observation simulations and image reconstruction.

See the [documentation](https://argos-telescope.github.io/argosim/) for installing and running Argosim.

Software developed at the [CosmoStat](https://www.cosmostat.org/) laboratory, CEA, Paris-Saclay, for the [ARGOS](https://argos-telescope.eu) telescope.
